exceptiontools.DurationError
============================

.. inheritance-diagram:: abjad.tools.exceptiontools.DurationError.DurationError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.DurationError.DurationError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
